pub struct InternalError(pub String);Expand description
An internal invariant was violated (e.g. a poisoned lock). Should not occur
in correct usage; surfaced rather than panicking so it crosses the FFI
boundary as a Result failure.
Tuple Fields
0: StringTrait Implementations
Sourceimpl AuthErrorKind for InternalError
impl AuthErrorKind for InternalError
Sourcefn error_code(&self) -> &'static str
fn error_code(&self) -> &'static str
Stable machine-readable identifier surfaced across FFI boundaries
(e.g. JS
Error.code). Named error_code to avoid colliding with
miette::Diagnostic::code, inherited via the Diagnostic supertrait.Sourceimpl Debug for InternalError
impl Debug for InternalError
Sourceimpl Diagnostic for InternalError
impl Diagnostic for InternalError
Sourcefn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
Unique diagnostic code that can be used to look up more information
about this
Diagnostic. Ideally also globally unique, and documented
in the toplevel crate’s documentation for easy searching. Rust path
format (foo::bar::baz) is recommended, but more classic codes like
E0123 or enums will work just fine.Sourcefn severity(&self) -> Option<Severity>
fn severity(&self) -> Option<Severity>
Diagnostic severity. This may be used by
ReportHandlers to change the display format
of this diagnostic. Read moreSourcefn help<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn help<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
Additional help text related to this
Diagnostic. Do you have any
advice for the poor soul who’s just run into this issue?Sourcefn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
URL to visit for a more detailed explanation/help about this
Diagnostic.Sourcefn source_code(&self) -> Option<&dyn SourceCode>
fn source_code(&self) -> Option<&dyn SourceCode>
Source code to apply this
Diagnostic’s Diagnostic::labels to.Sourcefn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
fn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
Labels to apply to this
Diagnostic’s Diagnostic::source_codeAdditional related
Diagnostics.Sourcefn diagnostic_source(&self) -> Option<&dyn Diagnostic>
fn diagnostic_source(&self) -> Option<&dyn Diagnostic>
The cause of the error.
Sourceimpl Display for InternalError
impl Display for InternalError
Sourceimpl Error for InternalError
impl Error for InternalError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<InternalError> for AuthError
impl From<InternalError> for AuthError
Sourcefn from(source: InternalError) -> Self
fn from(source: InternalError) -> Self
Converts to this type from the input type.