pub struct InvalidToken(pub String);Expand description
The JWT could not be decoded or its claims are malformed.
Tuple Fields
0: StringTrait Implementations
Sourceimpl AuthErrorKind for InvalidToken
impl AuthErrorKind for InvalidToken
Sourcefn error_code(&self) -> &'static str
fn error_code(&self) -> &'static str
Stable machine-readable identifier surfaced across FFI boundaries
(e.g. JS
Error.code). Named error_code to avoid colliding with
miette::Diagnostic::code, inherited via the Diagnostic supertrait.Sourceimpl Debug for InvalidToken
impl Debug for InvalidToken
Sourceimpl Diagnostic for InvalidToken
impl Diagnostic for InvalidToken
Sourcefn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
Unique diagnostic code that can be used to look up more information
about this
Diagnostic. Ideally also globally unique, and documented
in the toplevel crate’s documentation for easy searching. Rust path
format (foo::bar::baz) is recommended, but more classic codes like
E0123 or enums will work just fine.Sourcefn severity(&self) -> Option<Severity>
fn severity(&self) -> Option<Severity>
Diagnostic severity. This may be used by
ReportHandlers to change the display format
of this diagnostic. Read moreSourcefn help<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn help<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
Additional help text related to this
Diagnostic. Do you have any
advice for the poor soul who’s just run into this issue?Sourcefn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
URL to visit for a more detailed explanation/help about this
Diagnostic.Sourcefn source_code(&self) -> Option<&dyn SourceCode>
fn source_code(&self) -> Option<&dyn SourceCode>
Source code to apply this
Diagnostic’s Diagnostic::labels to.Sourcefn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
fn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
Labels to apply to this
Diagnostic’s Diagnostic::source_codeAdditional related
Diagnostics.Sourcefn diagnostic_source(&self) -> Option<&dyn Diagnostic>
fn diagnostic_source(&self) -> Option<&dyn Diagnostic>
The cause of the error.
Sourceimpl Display for InvalidToken
impl Display for InvalidToken
Sourceimpl Error for InvalidToken
impl Error for InvalidToken
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<InvalidToken> for AuthError
impl From<InvalidToken> for AuthError
Sourcefn from(source: InvalidToken) -> Self
fn from(source: InvalidToken) -> Self
Converts to this type from the input type.