pub struct OAuthStrategy { /* private fields */ }Expand description
An AuthStrategy that uses OAuth refresh tokens to maintain a valid access token.
Construction
Use OAuthStrategy::with_token with a token obtained from a device code flow
(or any other OAuth flow) for in-memory caching only. Use
OAuthStrategy::with_profile to load a token from disk and persist
refreshed tokens back to the store.
Example
use stack_auth::{OAuthStrategy, Token};
use cts_common::Region;
let region = Region::aws("ap-southeast-2")?;
let strategy = OAuthStrategy::with_token(region, "my-client-id", token).build()?;Implementations
Sourceimpl OAuthStrategy
impl OAuthStrategy
Sourcepub fn with_token(
region: Region,
client_id: impl Into<String>,
token: Token,
) -> OAuthStrategyBuilder
pub fn with_token( region: Region, client_id: impl Into<String>, token: Token, ) -> OAuthStrategyBuilder
Return a builder for configuring an OAuthStrategy from a token.
The token’s region and client_id fields are set before caching.
No token store is used — tokens are not persisted to disk.
Sourcepub fn with_profile(store: ProfileStore) -> OAuthStrategyBuilder
pub fn with_profile(store: ProfileStore) -> OAuthStrategyBuilder
Return a builder for configuring an OAuthStrategy from a profile store.
The token is loaded from the store when OAuthStrategyBuilder::build is called.
The builder allows further configuration (e.g. overriding the base URL) before building.
The token must have region and client_id set (as saved by
DeviceCodeStrategy or a prior
OAuthStrategy). The store is used for persisting refreshed tokens.
Sourcepub fn workspace_crn(&self) -> Option<&Crn>
pub fn workspace_crn(&self) -> Option<&Crn>
Return the workspace CRN, if one was extracted from the token at build time.