DeviceSessionStrategy

Struct DeviceSessionStrategy 

pub struct DeviceSessionStrategy { /* private fields */ }
An AuthStrategy that renews a CTS session minted by an interactive OAuth login (the device-code flow), using its OAuth refresh token.

This renews an existing CTS session — it cannot federate a raw third-party JWT. For that, see OidcFederationStrategy.

Construction

Use DeviceSessionStrategy::with_token with a token obtained from a device code flow (or any other OAuth flow) for in-memory caching only. Use DeviceSessionStrategy::with_profile to load a token from disk and persist refreshed tokens back to the store.

Example

use stack_auth::{DeviceSessionStrategy, Token};
use cts_common::Region;

let region = Region::aws("ap-southeast-2")?;
let strategy = DeviceSessionStrategy::with_token(region, "my-client-id", token).build()?;

Implementations

Source

impl DeviceSessionStrategy

pub fn with_token( region: Region, client_id: impl Into<String>, token: Token, ) -> DeviceSessionStrategyBuilder

Return a builder for configuring a DeviceSessionStrategy from a token.

The token’s region and client_id fields are set before caching. No token store is used — tokens are not persisted to disk.

pub fn with_profile(store: ProfileStore) -> DeviceSessionStrategyBuilder

Return a builder for configuring a DeviceSessionStrategy from a profile store.

The token is loaded from the store when DeviceSessionStrategyBuilder::build is called. The builder allows further configuration (e.g. overriding the base URL) before building.

The token must have region and client_id set (as saved by DeviceCodeStrategy or a prior DeviceSessionStrategy). The store is used for persisting refreshed tokens.

pub fn workspace_crn(&self) -> Option<&Crn>

Return the workspace CRN, if one was extracted from the token at build time.